"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Pantone = exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/extends"));

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/objectWithoutPropertiesLoose"));

var _react = _interopRequireWildcard(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _lodash = _interopRequireDefault(require("lodash.debounce"));

var _reactUse = require("react-use");

var _color = _interopRequireDefault(require("color"));

var _useControlledState2 = _interopRequireDefault(require("../../hooks/useControlledState/useControlledState"));

var _useColorAPINameHook = _interopRequireDefault(require("./useColorAPINameHook.hook"));

var _Base = _interopRequireDefault(require("../Base.core"));

require("./Pantone.scss");

var _jsxRuntime = require("react/jsx-runtime");

/* eslint react/prop-types: 0 */
var fromPercent = function fromPercent(valNum) {
  var decimalValue = Math.round(valNum * 255 / 100);
  var hexValue;

  if (valNum < 7) {
    hexValue = '0' + decimalValue.toString(16).toUpperCase();
  } else {
    hexValue = decimalValue.toString(16).toUpperCase();
  }

  return hexValue;
};

var DISPLAY_MODES = {
  HEX: function HEX(color) {
    return "" + color.hex() + fromPercent(color.valpha * 100);
  },
  RGB: function RGB(color) {
    return color.rgb().string();
  },
  HSL: function HSL(color) {
    return color.hsl().string();
  },
  CMYK: function CMYK(color) {
    return "cmyk(" + color.cmyk().round().array().join(', ').toString() + ")";
  }
};
var DEFAULT_DISPLAY_MODE = 'HEX';
var DEFAULT_COLOR = 'transparent';

var clickHandler = function clickHandler(_ref) {
  var color = _ref.color,
      setMode = _ref.setMode,
      mode = _ref.mode,
      onClick = _ref.onClick,
      onDoubleClick = _ref.onDoubleClick,
      tokenName = _ref.tokenName,
      copyToClipboard = _ref.copyToClipboard;
  return function (event) {
    switch (event.detail) {
      case 1:
        if (mode || tokenName !== undefined) {
          copyToClipboard(tokenName || DISPLAY_MODES[mode](color));
        }

        if (typeof onClick === 'function') {
          onClick(event, color, mode);
        }

        break;

      case 2:
      default:
        setMode(Pantone.next({
          mode: mode,
          color: color
        }));

        if (typeof onDoubleClick === 'function') {
          onDoubleClick(event, color, mode);
        }

        break;
    }
  };
};
/**
 * Pantone card of the background element color
 */


var Pantone = /*#__PURE__*/(0, _react.forwardRef)(function (_ref2, forwardedRef) {
  var _ref2$elementType = _ref2.elementType,
      elementType = _ref2$elementType === void 0 ? 'div' : _ref2$elementType,
      _ref2$color = _ref2.color,
      colorProp = _ref2$color === void 0 ? DEFAULT_COLOR : _ref2$color,
      displayMode = _ref2.displayMode,
      _ref2$initialDisplayM = _ref2.initialDisplayMode,
      initialDisplayMode = _ref2$initialDisplayM === void 0 ? DEFAULT_DISPLAY_MODE : _ref2$initialDisplayM,
      className = _ref2.className,
      onClick = _ref2.onClick,
      onDoubleClick = _ref2.onDoubleClick,
      onDataFetched = _ref2.onDataFetched,
      name = _ref2.name,
      tokenName = _ref2.tokenName,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref2, ["elementType", "color", "displayMode", "initialDisplayMode", "className", "onClick", "onDoubleClick", "onDataFetched", "name", "tokenName"]);

  var _useControlledState = (0, _useControlledState2["default"])(displayMode, initialDisplayMode),
      mode = _useControlledState[0],
      setMode = _useControlledState[1];

  var _useState = (0, _react.useState)({
    value: name !== undefined ? name : undefined
  }),
      data = _useState[0],
      setData = _useState[1];

  var _useState2 = (0, _react.useState)((0, _color["default"])(colorProp)),
      color = _useState2[0],
      setColor = _useState2[1];

  var _useCopyToClipboard = (0, _reactUse.useCopyToClipboard)(),
      copyToClipboard = _useCopyToClipboard[1];

  (0, _useColorAPINameHook["default"])({
    HEXColor: DISPLAY_MODES.HEX(color).slice(1, 7),
    name: data.value
  }, function (value) {
    name === undefined && setData(value);
    typeof onDataFetched === 'function' && onDataFetched(value);
  });
  (0, _react.useEffect)(function () {
    setData({
      value: name !== undefined ? name : undefined
    });
  }, [name, setData]);
  (0, _react.useEffect)(function () {
    var value = (0, _color["default"])(colorProp);
    setColor(value);
  }, [colorProp, setColor]);
  var handleClick = (0, _react.useMemo)(function () {
    return (0, _lodash["default"])(clickHandler({
      color: color,
      setMode: setMode,
      mode: mode,
      onClick: onClick,
      onDoubleClick: onDoubleClick,
      tokenName: tokenName,
      copyToClipboard: copyToClipboard
    }), 200);
  }, [color, setMode, mode, onClick, onDoubleClick, tokenName]);
  var tiltColor = (0, _react.useMemo)(function () {
    if (typeof color !== 'object') {
      return 'transparent';
    } else if (color.isLight()) {
      return DISPLAY_MODES.HEX(color.darken(0.3));
    } else if (color.isDark()) {
      return DISPLAY_MODES.HEX(color.lighten(0.3));
    }
  }, [color]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Base["default"], (0, _extends2["default"])({}, props, {
    elementType: elementType,
    className: (0, _classnames["default"])('sui-studio-doc', 'sui-studio-doc-pantone', className),
    role: "button",
    onClick: handleClick,
    style: {
      backgroundColor: color ? DISPLAY_MODES[mode](color) : DEFAULT_COLOR
    },
    ref: forwardedRef,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
      className: "sui-studio-doc-pantone-frame-wrapper",
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Base["default"], {
        elementType: "div",
        className: (0, _classnames["default"])('sui-studio-doc', 'sui-studio-doc-pantone-frame', {
          'sui-studio-doc-pantone-frame-isLight': (color == null ? void 0 : color.isLight) && color.isLight(),
          'sui-studio-doc-pantone-frame-isDark': (color == null ? void 0 : color.isDark) && color.isDark()
        }),
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Base["default"], {
          elementType: "div",
          className: (0, _classnames["default"])('sui-studio-doc', 'sui-studio-doc-pantone-token-name', {
            'sui-studio-doc-pantone-token-name-isLight': (color == null ? void 0 : color.isLight) && color.isLight(),
            'sui-studio-doc-pantone-token-name-isDark': (color == null ? void 0 : color.isDark) && color.isDark()
          }),
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
            className: "sui-studio-doc-pantone-text",
            children: tokenName
          })
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Base["default"], {
          elementType: "div",
          className: (0, _classnames["default"])('sui-studio-doc', 'sui-studio-doc-pantone-legend', {
            'sui-studio-doc-pantone-legend-isLight': (color == null ? void 0 : color.isLight) && color.isLight(),
            'sui-studio-doc-pantone-legend-isDark': (color == null ? void 0 : color.isDark) && color.isDark()
          }),
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
            className: "sui-studio-doc-pantone-text",
            children: typeof mode === 'string' && DISPLAY_MODES[mode](color)
          })
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Base["default"], {
          elementType: "div",
          fontWeight: "bold",
          className: (0, _classnames["default"])('sui-studio-doc', 'sui-studio-doc-pantone-name', {
            'sui-studio-doc-pantone-legend-isLight': (color == null ? void 0 : color.isLight) && color.isLight(),
            'sui-studio-doc-pantone-legend-isDark': (color == null ? void 0 : color.isDark) && color.isDark()
          }),
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
            className: "sui-studio-doc-pantone-text",
            children: data.value !== null && data.value !== undefined ? data.value : '‎'
          })
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
          className: "sui-studio-doc-pantone-frame-tilt",
          style: {
            backgroundColor: tiltColor
          }
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
          className: "sui-studio-doc-pantone-frame-tilt",
          style: {
            backgroundColor: tiltColor
          }
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
          className: "sui-studio-doc-pantone-frame-tilt",
          style: {
            backgroundColor: tiltColor
          }
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
          className: "sui-studio-doc-pantone-frame-tilt",
          style: {
            backgroundColor: tiltColor
          }
        })]
      })
    })
  }));
});
exports.Pantone = Pantone;
Pantone.displayName = 'Pantone';
Pantone.defaultProps = {};

Pantone.mode = function (_ref3) {
  var color = _ref3.color,
      mode = _ref3.mode;
  var modeKeys = Object.keys(DISPLAY_MODES);

  if (modeKeys.includes(mode)) {
    return mode;
  }

  var response;

  switch (color.model) {
    case 'hsl':
      response = modeKeys.find(function (value) {
        return value === 'HSL';
      });
      break;

    case 'rgb':
    default:
      response = modeKeys.find(function (value) {
        return value === 'RGB';
      });
      break;
  }

  return response;
};

Pantone.next = function (_ref4) {
  var mode = _ref4.mode,
      color = _ref4.color;
  var modeKeys = Object.keys(DISPLAY_MODES);
  var index = modeKeys.indexOf(Pantone.mode({
    mode: mode,
    color: color
  }));

  if (index >= 0) {
    return modeKeys[(index + 1) % modeKeys.length];
  } else {
    return 'RGB';
  }
};

Pantone.displayMode = function (mode) {
  return function (color) {
    return DISPLAY_MODES[mode](color);
  };
};

var _default = Pantone;
exports["default"] = _default;