"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RadioGroup = exports.Radio = exports["default"] = exports.RadioGroupContext = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/extends"));

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/objectWithoutPropertiesLoose"));

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Base = _interopRequireDefault(require("../Base.core"));

var _Text = _interopRequireDefault(require("../Text/Text"));

var _useControlledState3 = _interopRequireDefault(require("../../hooks/useControlledState/useControlledState"));

require("./Radio.scss");

var _jsxRuntime = require("react/jsx-runtime");

/* eslint react/prop-types: 0 */
var RadioGroupContext = /*#__PURE__*/_react["default"].createContext();
/**
 * The `<input type="radio">` defines a radio button.
 * RadioButton buttons are normally presented in radio groups (a collection of radio buttons describing a set of related options). Only one radio button in a group can be selected at the same time.
 */


exports.RadioGroupContext = RadioGroupContext;
var Radio = /*#__PURE__*/(0, _react.forwardRef)(function (_ref, forwardedRef) {
  var label = _ref.label,
      className = _ref.className,
      _ref$elementType = _ref.elementType,
      elementType = _ref$elementType === void 0 ? 'input' : _ref$elementType,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'radio' : _ref$type,
      _ref$defaultChecked = _ref.defaultChecked,
      defaultChecked = _ref$defaultChecked === void 0 ? false : _ref$defaultChecked,
      onClick = _ref.onClick,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? function () {
    return null;
  } : _ref$onChange,
      checked = _ref.checked,
      value = _ref.value,
      name = _ref.name,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref, ["label", "className", "elementType", "type", "defaultChecked", "onClick", "onChange", "checked", "value", "name"]);
  var radioGroupContext = (0, _react.useContext)(RadioGroupContext) || {};
  var contextValue = radioGroupContext.value;
  var setContextState = radioGroupContext.setContextState;

  var _useControlledState = (0, _useControlledState3["default"])(checked, defaultChecked),
      checkedState = _useControlledState[0],
      setCheckedState = _useControlledState[1];

  (0, _react.useEffect)(function () {
    if (contextValue === undefined) {
      return;
    }

    if (value !== undefined) {
      setCheckedState(contextValue === value);
    }
  }, [contextValue, setCheckedState, value]);

  var onClickHandler = function onClickHandler(event) {
    var name = event.target.name;
    setCheckedState(!checkedState);

    if (setContextState && event.target.checked === true) {
      setContextState(event, {
        value: checkedState ? undefined : value,
        name: name
      });
    }

    if (onClick) {
      onClick(event, checkedState ? undefined : value);
    }
  };

  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Base["default"], (0, _extends2["default"])({}, props, {
      elementType: elementType,
      type: type,
      className: (0, _classnames["default"])('sui-studio-doc-radio', className),
      onClick: onClickHandler,
      onChange: onChange,
      checked: checkedState,
      "aria-label": label || value,
      value: value,
      name: name || radioGroupContext.name,
      ref: forwardedRef
    })), (label || value) && /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text["default"], {
      elementType: "label",
      children: label || value
    })]
  });
});
exports.Radio = Radio;
Radio.displayName = 'Radio';
Radio.defaultProps = {};
/**
 * Radio options element wrapper
 */

var RadioGroup = /*#__PURE__*/(0, _react.forwardRef)(function (_ref2, forwardedRef) {
  var className = _ref2.className,
      children = _ref2.children,
      _ref2$elementType = _ref2.elementType,
      elementType = _ref2$elementType === void 0 ? 'div' : _ref2$elementType,
      defaultValue = _ref2.defaultValue,
      value = _ref2.value,
      label = _ref2.label,
      name = _ref2.name,
      onChange = _ref2.onChange,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref2, ["className", "children", "elementType", "defaultValue", "value", "label", "name", "onChange"]);

  var _useControlledState2 = (0, _useControlledState3["default"])(value, defaultValue),
      valueState = _useControlledState2[0],
      setValueState = _useControlledState2[1];

  var setContextState = function setContextState(event, newArguments) {
    if (newArguments === void 0) {
      newArguments = {};
    }

    var newContext = (0, _extends2["default"])({
      name: name,
      label: label,
      value: valueState
    }, newArguments);

    if (onChange) {
      onChange(event, newContext.value);
    }

    setValueState(newContext.value);
  };

  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Base["default"], (0, _extends2["default"])({}, props, {
    className: (0, _classnames["default"])('sui-studio-doc-radio-group', className),
    elementType: elementType,
    role: "radiogroup",
    "aria-labelledby": label,
    name: name,
    ref: forwardedRef,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(RadioGroupContext.Provider, {
      value: {
        name: name,
        label: label,
        value: valueState,
        setContextState: setContextState
      },
      children: children
    })
  }));
});
exports.RadioGroup = RadioGroup;
RadioGroup.displayName = 'RadioGroup';
RadioGroup.defaultProps = {};
var _default = Radio;
exports["default"] = _default;