"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Superscript = exports.Subscript = exports.Inserted = exports.Deleted = exports.Small = exports.Mark = exports.Emphasis = exports.Idiomatic = exports.Strong = exports.Bold = exports.Text = exports["default"] = exports.TEXT_ELEMENT = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/extends"));

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/objectWithoutPropertiesLoose"));

var _react = _interopRequireWildcard(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Base = _interopRequireDefault(require("../Base.core"));

require("./Text.scss");

var _jsxRuntime = require("react/jsx-runtime");

/* eslint react/prop-types: 0 */
var TEXT_ELEMENT = {
  b: {
    elementType: 'b',
    className: function className(cn) {
      return (0, _classnames["default"])('sui-studio-doc-text', 'sui-studio-doc-text-bold', cn);
    }
  },
  strong: {
    elementType: 'strong',
    className: function className(cn) {
      return (0, _classnames["default"])('sui-studio-doc-text', 'sui-studio-doc-text-strong', cn);
    }
  },
  i: {
    elementType: 'i',
    className: function className(cn) {
      return (0, _classnames["default"])('sui-studio-doc-text', 'sui-studio-doc-text-italic', cn);
    }
  },
  em: {
    elementType: 'em',
    className: function className(cn) {
      return (0, _classnames["default"])('sui-studio-doc-text', 'sui-studio-doc-text-emphasized', cn);
    }
  },
  mark: {
    elementType: 'mark',
    className: function className(cn) {
      return (0, _classnames["default"])('sui-studio-doc-text', 'sui-studio-doc-text-marked', cn);
    }
  },
  small: {
    elementType: 'small',
    className: function className(cn) {
      return (0, _classnames["default"])('sui-studio-doc-text', 'sui-studio-doc-text-small', cn);
    }
  },
  del: {
    elementType: 'del',
    className: function className(cn) {
      return (0, _classnames["default"])('sui-studio-doc-text', 'sui-studio-doc-text-deleted', cn);
    }
  },
  ins: {
    elementType: 'ins',
    className: function className(cn) {
      return (0, _classnames["default"])('sui-studio-doc-text', 'sui-studio-doc-text-inserted', cn);
    }
  },
  sub: {
    elementType: 'sub',
    className: function className(cn) {
      return (0, _classnames["default"])('sui-studio-doc-text', 'sui-studio-doc-text-subscript', cn);
    }
  },
  sup: {
    elementType: 'sup',
    className: function className(cn) {
      return (0, _classnames["default"])('sui-studio-doc-text', 'sui-studio-doc-text-superscript', cn);
    }
  }
};
/**
 * Simple plain text styled
 */

exports.TEXT_ELEMENT = TEXT_ELEMENT;
var Text = /*#__PURE__*/(0, _react.forwardRef)(function (_ref, forwardedRef) {
  var _ref$elementType = _ref.elementType,
      elementType = _ref$elementType === void 0 ? 'span' : _ref$elementType,
      className = _ref.className,
      children = _ref.children,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref, ["elementType", "className", "children"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Base["default"], (0, _extends2["default"])({}, props, {
    elementType: elementType,
    className: (0, _classnames["default"])('sui-studio-doc-text', className),
    ref: forwardedRef,
    children: children
  }));
});
exports.Text = Text;
Text.displayName = 'Text';
Text.propTypes = {};
Text.defaultProps = {};
/**
 * The HTML Bring Attention To element (`b`) is used to draw the reader's attention to the element's contents, which are not otherwise granted special importance.
 */

var Bold = /*#__PURE__*/(0, _react.forwardRef)(function (_ref2, forwardedRef) {
  var children = _ref2.children,
      className = _ref2.className,
      _ref2$elementType = _ref2.elementType,
      elementType = _ref2$elementType === void 0 ? TEXT_ELEMENT.b.elementType : _ref2$elementType,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref2, ["children", "className", "elementType"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(Text, (0, _extends2["default"])({}, props, {
    className: TEXT_ELEMENT.b.className(className),
    elementType: elementType,
    ref: forwardedRef,
    children: children
  }));
});
exports.Bold = Bold;
Bold.displayName = 'Bold';
Bold.propTypes = {};
Bold.defaultProps = {};
/**
 * The HTML Strong Importance Element (`strong`) indicates that its contents have strong importance, seriousness, or urgency. Browsers typically render the contents in bold type.
 */

var Strong = /*#__PURE__*/(0, _react.forwardRef)(function (_ref3, forwardedRef) {
  var children = _ref3.children,
      className = _ref3.className,
      _ref3$elementType = _ref3.elementType,
      elementType = _ref3$elementType === void 0 ? TEXT_ELEMENT.strong.elementType : _ref3$elementType,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref3, ["children", "className", "elementType"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(Text, (0, _extends2["default"])({}, props, {
    className: TEXT_ELEMENT.strong.className(className),
    elementType: elementType,
    ref: forwardedRef,
    children: children
  }));
});
exports.Strong = Strong;
Strong.displayName = 'Strong';
Strong.propTypes = {};
Strong.defaultProps = {};
/**
 * The HTML Idiomatic Text element (`i`) represents a range of text that is set off from the normal text for some reason, such as idiomatic text, technical terms, taxonomical designations, among others.
 */

var Idiomatic = /*#__PURE__*/(0, _react.forwardRef)(function (_ref4, forwardedRef) {
  var children = _ref4.children,
      className = _ref4.className,
      _ref4$elementType = _ref4.elementType,
      elementType = _ref4$elementType === void 0 ? TEXT_ELEMENT.i.elementType : _ref4$elementType,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref4, ["children", "className", "elementType"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(Text, (0, _extends2["default"])({}, props, {
    elementType: elementType,
    className: TEXT_ELEMENT.i.className(className),
    ref: forwardedRef,
    children: children
  }));
});
exports.Idiomatic = Idiomatic;
Idiomatic.displayName = 'Idiomatic';
Idiomatic.propTypes = {};
Idiomatic.defaultProps = {};
/**
 * The HTML `em` element marks text that has stress emphasis. The <em> element can be nested, with each level of nesting indicating a greater degree of emphasis.
 */

var Emphasis = /*#__PURE__*/(0, _react.forwardRef)(function (_ref5, forwardedRef) {
  var children = _ref5.children,
      className = _ref5.className,
      _ref5$elementType = _ref5.elementType,
      elementType = _ref5$elementType === void 0 ? TEXT_ELEMENT.em.elementType : _ref5$elementType,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref5, ["children", "className", "elementType"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(Text, (0, _extends2["default"])({}, props, {
    elementType: elementType,
    className: TEXT_ELEMENT.em.className(className),
    ref: forwardedRef,
    children: children
  }));
});
exports.Emphasis = Emphasis;
Emphasis.displayName = 'Emphasis';
Emphasis.propTypes = {};
Emphasis.defaultProps = {};
/**
 * The HTML Mark Text element (`mark`) represents text which is marked or highlighted for reference or notation purposes, due to the marked passage's relevance or importance in the enclosing context.
 */

var Mark = /*#__PURE__*/(0, _react.forwardRef)(function (_ref6, forwardedRef) {
  var children = _ref6.children,
      className = _ref6.className,
      _ref6$elementType = _ref6.elementType,
      elementType = _ref6$elementType === void 0 ? TEXT_ELEMENT.mark.elementType : _ref6$elementType,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref6, ["children", "className", "elementType"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(Text, (0, _extends2["default"])({}, props, {
    elementType: elementType,
    className: TEXT_ELEMENT.mark.className(className),
    ref: forwardedRef,
    children: children
  }));
});
exports.Mark = Mark;
Mark.displayName = 'Mark';
Mark.propTypes = {};
Mark.defaultProps = {};
/**
 * The HTML `small element represents side-comments and small print, like copyright and legal text, independent of its styled presentation. By default, it renders text within it one font-size smaller, such as from small to x-small
 */

var Small = /*#__PURE__*/(0, _react.forwardRef)(function (_ref7, forwardedRef) {
  var children = _ref7.children,
      className = _ref7.className,
      _ref7$elementType = _ref7.elementType,
      elementType = _ref7$elementType === void 0 ? TEXT_ELEMENT.small.elementType : _ref7$elementType,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref7, ["children", "className", "elementType"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(Text, (0, _extends2["default"])({}, props, {
    elementType: elementType,
    className: TEXT_ELEMENT.small.className(className),
    ref: forwardedRef,
    children: children
  }));
});
exports.Small = Small;
Small.displayName = 'Small';
Small.propTypes = {};
Small.defaultProps = {};
/**
 * 	The HTML `del` element represents a range of text that has been deleted from a document.
 */

var Deleted = /*#__PURE__*/(0, _react.forwardRef)(function (_ref8, forwardedRef) {
  var children = _ref8.children,
      className = _ref8.className,
      _ref8$elementType = _ref8.elementType,
      elementType = _ref8$elementType === void 0 ? TEXT_ELEMENT.del.elementType : _ref8$elementType,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref8, ["children", "className", "elementType"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(Text, (0, _extends2["default"])({}, props, {
    elementType: elementType,
    className: TEXT_ELEMENT.del.className(className),
    ref: forwardedRef,
    children: children
  }));
});
exports.Deleted = Deleted;
Deleted.displayName = 'Deleted';
Deleted.propTypes = {};
Deleted.defaultProps = {};
/**
 * 	The HTML `ins` element represents a range of text that has been added to a document.
 */

var Inserted = /*#__PURE__*/(0, _react.forwardRef)(function (_ref9, forwardedRef) {
  var children = _ref9.children,
      className = _ref9.className,
      _ref9$elementType = _ref9.elementType,
      elementType = _ref9$elementType === void 0 ? TEXT_ELEMENT.ins.elementType : _ref9$elementType,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref9, ["children", "className", "elementType"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(Text, (0, _extends2["default"])({}, props, {
    elementType: elementType,
    className: TEXT_ELEMENT.ins.className(className),
    ref: forwardedRef,
    children: children
  }));
});
exports.Inserted = Inserted;
Inserted.displayName = 'Inserted';
Inserted.propTypes = {};
Inserted.defaultProps = {};
/**
 * The HTML Subscript element (`sub`) specifies inline text which should be displayed as subscript for solely typographical reasons.
 */

var Subscript = /*#__PURE__*/(0, _react.forwardRef)(function (_ref10, forwardedRef) {
  var children = _ref10.children,
      className = _ref10.className,
      _ref10$elementType = _ref10.elementType,
      elementType = _ref10$elementType === void 0 ? TEXT_ELEMENT.sub.elementType : _ref10$elementType,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref10, ["children", "className", "elementType"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(Text, (0, _extends2["default"])({}, props, {
    elementType: elementType,
    className: TEXT_ELEMENT.sub.className(className),
    ref: forwardedRef,
    children: children
  }));
});
exports.Subscript = Subscript;
Subscript.displayName = 'Subscript';
Subscript.propTypes = {};
Subscript.defaultProps = {};
/**
 * The HTML Superscript element (`sup`) specifies inline text which is to be displayed as superscript for solely typographical reasons.
 */

var Superscript = /*#__PURE__*/(0, _react.forwardRef)(function (_ref11, forwardedRef) {
  var children = _ref11.children,
      className = _ref11.className,
      _ref11$elementType = _ref11.elementType,
      elementType = _ref11$elementType === void 0 ? TEXT_ELEMENT.sup.elementType : _ref11$elementType,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref11, ["children", "className", "elementType"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(Text, (0, _extends2["default"])({}, props, {
    elementType: elementType,
    className: TEXT_ELEMENT.sup.className(className),
    ref: forwardedRef,
    children: children
  }));
});
exports.Superscript = Superscript;
Superscript.displayName = 'Superscript';
Superscript.propTypes = {};
Superscript.defaultProps = {};
var _default = Text;
exports["default"] = _default;