"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _reactHooks = require("@testing-library/react-hooks");

var _useControlledState = _interopRequireDefault(require("./useControlledState"));

describe('hooks', function () {
  describe('useControlledState hook', function () {
    var setupHook = function setupHook(props) {
      return (0, _reactHooks.renderHook)(function () {
        return (0, _useControlledState["default"])(props.value, props.defaultValue);
      });
    };

    afterEach(_reactHooks.cleanup);
    it('given no value and default value should return defaultValue and do not update its value until a controlled value is set', function () {
      // Given
      var props = {
        value: undefined,
        defaultValue: 123
      }; // When

      var hook = setupHook(props);
      var _hook$result$current = hook.result.current,
          response = _hook$result$current[0],
          setResponse = _hook$result$current[1],
          isControlledValue = _hook$result$current[2],
          initialValue = _hook$result$current[3]; // Then

      expect(typeof response).toBe('number');
      expect(typeof setResponse).toBe('function');
      expect(typeof isControlledValue).toBe('boolean');
      expect(typeof initialValue).toBe('number');
      expect(response).toBe(123);
      expect(isControlledValue).toBe(false);
      expect(initialValue).toBe(123); // And
      // Given

      props.defaultValue = 456; // When

      hook.rerender(props);
      var _hook$result$current2 = hook.result.current;
      response = _hook$result$current2[0];
      setResponse = _hook$result$current2[1];
      isControlledValue = _hook$result$current2[2];
      initialValue = _hook$result$current2[3];
      // Then
      expect(typeof response).toBe('number');
      expect(typeof setResponse).toBe('function');
      expect(typeof isControlledValue).toBe('boolean');
      expect(typeof initialValue).toBe('number');
      expect(response).toBe(123);
      expect(isControlledValue).toBe(false);
      expect(initialValue).toBe(123); // And
      // Given

      props.value = 789; // When

      hook.rerender(props);
      var _hook$result$current3 = hook.result.current;
      response = _hook$result$current3[0];
      setResponse = _hook$result$current3[1];
      isControlledValue = _hook$result$current3[2];
      initialValue = _hook$result$current3[3];
      // Then
      expect(typeof response).toBe('number');
      expect(typeof setResponse).toBe('function');
      expect(typeof isControlledValue).toBe('boolean');
      expect(typeof initialValue).toBe('number');
      expect(response).toBe(789);
      expect(isControlledValue).toBe(true);
      expect(initialValue).toBe(123);
    });
    it('value must be more relevant than defaultValue', function () {
      // Given
      var props = {
        value: 123,
        defaultValue: 456
      }; // When

      var hook = setupHook(props);
      var _hook$result$current4 = hook.result.current,
          response = _hook$result$current4[0],
          setResponse = _hook$result$current4[1],
          isControlledValue = _hook$result$current4[2],
          initialValue = _hook$result$current4[3]; // Then

      expect(typeof response).toBe('number');
      expect(typeof setResponse).toBe('function');
      expect(typeof isControlledValue).toBe('boolean');
      expect(typeof initialValue).toBe('number');
      expect(response).toBe(123);
      expect(isControlledValue).toBe(true);
      expect(initialValue).toBe(123);
    });
    it('value must be updated using its setter when using uncontrolled mode and blocked when using controlled mode', function () {
      // Given
      var props = {
        value: undefined,
        defaultValue: 123
      }; // When

      var hook = setupHook(props);
      var _hook$result$current5 = hook.result.current,
          response = _hook$result$current5[0],
          setResponse = _hook$result$current5[1],
          isControlledValue = _hook$result$current5[2],
          initialValue = _hook$result$current5[3]; // Then

      expect(typeof response).toBe('number');
      expect(typeof setResponse).toBe('function');
      expect(typeof isControlledValue).toBe('boolean');
      expect(typeof initialValue).toBe('number');
      expect(response).toBe(123);
      expect(isControlledValue).toBe(false);
      expect(initialValue).toBe(123); // And
      // When

      (0, _reactHooks.act)(function () {
        setResponse(456);
      });
      var _hook$result$current6 = hook.result.current;
      response = _hook$result$current6[0];
      // Then
      expect(isControlledValue).toBe(false);
      expect(response).toBe(456); // And
      // Then

      props.value = 789; // When

      hook.rerender(props);
      var _hook$result$current7 = hook.result.current;
      setResponse = _hook$result$current7[1];
      (0, _reactHooks.act)(function () {
        setResponse(123);
      });
      var _hook$result$current8 = hook.result.current;
      response = _hook$result$current8[0];
      isControlledValue = _hook$result$current8[2];
      // Then
      expect(isControlledValue).toBe(true);
      expect(response).toBe(789);
    });
  });
});