"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/extends"));

var _react = _interopRequireWildcard(require("react"));

var _react2 = require("@testing-library/react");

var _useMergeRefs = _interopRequireDefault(require("./useMergeRefs"));

var _jsxRuntime = require("react/jsx-runtime");

describe('hooks', function () {
  describe('useMergeRefs hook', function () {
    it('should merge all the passed refs into a single one', function () {
      var refs = {};

      function TestComponent() {
        var firstRef = (0, _react.useRef)();
        var secondRef = (0, _react.useRef)();
        var thirdRef = (0, _react.useRef)();
        var ref = (0, _useMergeRefs["default"])(firstRef, secondRef, thirdRef);
        (0, _react.useEffect)(function () {
          refs.first = firstRef.current;
          refs.second = secondRef.current;
          refs.third = thirdRef.current;
        }, []);
        return /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
          ref: ref
        });
      }

      (0, _react2.render)( /*#__PURE__*/(0, _jsxRuntime.jsx)(TestComponent, {}));
      expect(refs.first).toBe(refs.second);
      expect(refs.first).toBe(refs.third);
      expect(refs.second).toBe(refs.third);
    });
    it('should merge both functional and object references', function () {
      var refs = {};

      var TestComponent = /*#__PURE__*/_react["default"].forwardRef(function TestComponent(props, forwardedRef) {
        var firstRef = (0, _react.useRef)();
        var secondRef = (0, _react.useRef)();
        var ref = (0, _useMergeRefs["default"])(firstRef, secondRef, forwardedRef);
        (0, _react.useEffect)(function () {
          refs.first = firstRef.current;
          refs.second = secondRef.current;
        }, []);
        return /*#__PURE__*/(0, _jsxRuntime.jsx)("div", (0, _extends2["default"])({
          ref: ref
        }, props));
      });

      var refToBeForwarded = /*#__PURE__*/_react["default"].createRef();

      (0, _react2.render)( /*#__PURE__*/(0, _jsxRuntime.jsx)(TestComponent, {
        ref: function ref(node) {
          return refToBeForwarded.current = node;
        }
      }));
      expect(refs.first).toBe(refs.second);
      expect(refs.first).toBe(refToBeForwarded.current);
      expect(refs.second).toBe(refToBeForwarded.current);
    });
  });
});