"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = require("react");

/**
 *
 * useMutationObserver hook
 *
 * Returns a mutation observer for a React Ref and fires a callback
 *
 * @param ref React ref on which mutations are to be observed
 * @param callback Function that needs to be fired on mutation
 * @param options
 */
var useMutationObserver = function useMutationObserver(ref, callback, options) {
  (0, _react.useEffect)(function () {
    // Create an observer instance linked to the callback function
    if (ref.current) {
      var observer = new MutationObserver(callback); // Start observing the target node for configured mutations

      observer.observe(ref.current, options);
      return function () {
        // closes the observer before unmounting.
        observer.disconnect();
      };
    }
  }, [callback, options, ref]);
};

var _default = useMutationObserver;
exports["default"] = _default;