"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = require("react");

function resolvePromise(promise) {
  if (typeof promise === 'function') {
    return promise();
  }

  return promise;
}

var states = {
  PENDING: 'pending',
  REJECTED: 'rejected',
  RESOLVED: 'resolved'
};
var defaultState = {
  error: undefined,
  result: undefined,
  state: states.PENDING
};

function reducer(state, action) {
  switch (action.type) {
    case states.PENDING:
      return defaultState;

    case states.RESOLVED:
      return {
        error: undefined,
        result: action.payload,
        state: states.RESOLVED
      };

    case states.REJECTED:
      return {
        error: action.payload,
        result: undefined,
        state: states.REJECTED
      };

    default:
      return state;
  }
}

function usePromise(promise, inputs) {
  var _useReducer = (0, _react.useReducer)(reducer, defaultState),
      _useReducer$ = _useReducer[0],
      error = _useReducer$.error,
      result = _useReducer$.result,
      state = _useReducer$.state,
      dispatch = _useReducer[1];

  (0, _react.useEffect)(function () {
    promise = resolvePromise(promise);

    if (!promise) {
      return;
    }

    var canceled = false;
    dispatch({
      type: states.PENDING
    });
    promise.then(function (result) {
      return !canceled && dispatch({
        payload: result,
        type: states.RESOLVED
      });
    }, function (error) {
      return !canceled && dispatch({
        payload: error,
        type: states.REJECTED
      });
    });
    return function () {
      canceled = true;
    };
  }, inputs);
  return [result, error, state];
}

var _default = usePromise;
exports["default"] = _default;